#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ Web 测试套件 ]

"""

# from rains.kit.web.web_driver import WebDriver
# from rains.kit.web.web_task import WebTask
# from rains.kit.web.web_plant import BY
# from rains.kit.web.web_plant import WebPlant
# from rains.kit.web.web_plant import WebPlantElement


# __all__ = [
#     'WebDriver', 
#     'WebTask', 
#     'BY', 
#     'WebPlant', 
#     'WebPlantElement'
# ]
